@@ -188,7 +188,7 @@ import sys
 from mako.lookup import TemplateLookup
 from mako.exceptions import TopLevelLookupException
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 """
 The current version of pdoc. This value is read from `setup.py`.
 """
@@ -611,7 +611,7 @@ class Module (Doc):
                 for f in docobj.functions():
                     self.refdoc[f.refname] = f
 
-        # Finally look for more docstrings in the __pdoc override.
+        # Finally look for more docstrings in the __pdoc__ override.
         for name, docstring in getattr(self.module, '__pdoc__', {}).items():
             dobj = self.find_ident('%s.%s' % (self.refname, name))
             if isinstance(dobj, External):
@@ -882,6 +882,9 @@ class Class (Doc):
             # Skip any identifiers that already have doco.
             if name in self.doc and not self.doc[name].is_empty():
                 continue
+            if name in self.doc_init:
+                # Let instance members override class members.
+                continue
 
             if inspect.ismethod(obj):
                 self.doc[name] = Function(name, self.module, obj.__func__,
@@ -890,14 +893,16 @@ class Class (Doc):
                 self.doc[name] = Function(name, self.module, obj,
                                           cls=self, method=False)
             elif isinstance(obj, property):
-                docstring = ''
-                if hasattr(obj, '__doc__'):
-                    docstring = obj.__doc__
+                docstring = getattr(obj, '__doc__', '')
                 self.doc_init[name] = Variable(name, self.module, docstring,
                                                cls=self)
             elif not inspect.isbuiltin(obj) \
                     and not inspect.isroutine(obj):
-                self.doc[name] = Variable(name, self.module, '', cls=self)
+                if name in getattr(self.cls, '__slots__', []):
+                    self.doc_init[name] = Variable(name, self.module,
+                                                   '', cls=self)
+                else:
+                    self.doc[name] = Variable(name, self.module, '', cls=self)
 
     @property
     def source(self):
@@ -1080,7 +1085,7 @@ class Function (Doc):
 
         # TODO: This needs to be adjusted in Python 3. There's more stuff
         #       returned from getfullargspec than what we're looking at here.
-        keywords = getattr(s, 'varkw', 'keywords')
+        keywords = getattr(s, 'varkw', s.keywords)
         if keywords is not None:
             params.append('**%s' % keywords)
         return params
